/**
 * Neociclo Accord, Open Source B2Bi Middleware
 * Copyright (C) 2005-2009 Neociclo, http://www.neociclo.com
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $Id: OdetteFtpConstants.java 411 2010-06-21 14:55:04Z rmarins $
 */
package org.neociclo.odetteftp.util;

import org.neociclo.odetteftp.EntityType;
import org.neociclo.odetteftp.OdetteFtpVersion;
import org.neociclo.odetteftp.protocol.v20.CipherSuite;

/**
 * @author Rafael Marins
 * @version $Rev: 411 $ $Date: 2010-06-21 11:55:04 -0300 (Mon, 21 Jun 2010) $
 */
public class OdetteFtpConstants {

    /**
     * Maximum Exchange Buffer length allowed by protocol specification.
     */
    public static final int MAX_OEB_LENGTH = 99999;

    /**
     * Minimum Exchange Buffer length allowed by protocol specification.
     */
    public static final int MIN_OEB_LENGTH = 128;

    /**
     * Default ODETTE-FTP session timeout of 90 seconds.
     */
    public static final int DEFAULT_OFTP_SESSION_TIMEOUT = 90;

    /**
     * Default Data Exchange Buffer size of 4096 octets.
     */
    public static final int DEFAULT_OFTP_DATA_EXCHANGE_BUFFER = 4096;

    public static final int DEFAULT_OFTP_WINDOW_SIZE = 64;

    public static final int DEFAULT_RECORD_SIZE = 1024;

    /**
     * Use ODETTE-FTP v2.0 secure authentication option is disabled by default.
     */
    public static final boolean DEFAULT_OFTP_V20_SECURE_AUTH = false;

    public static final boolean DEFAULT_OFTP_RESTART = true;

    public static final boolean DEFAULT_OFTP_BUFFER_COMPRESSION = false;

    public static final boolean DEFAULT_OFTP_SPECIAL_LOGIC = false;

    public static final OdetteFtpVersion DEFAULT_OFTP_VERSION = OdetteFtpVersion.OFTP_V20;

    public static final EntityType DEFAULT_OFTP_ENTITY_TYPE = EntityType.INITIATOR;

    /**
     * Use 3DES_EDE_CBC_3KEY by default.
     */
    public static final CipherSuite DEFAULT_OFTP2_CIPHER_SUITE = CipherSuite.TRIPLEDES_RSA_SHA1;

    public static final String DEFAULT_LOGGING_LEVEL = "INFO";

    /**
     * A random number uniquely generated each time an Authentication Challenged
     * is sent. Since Odette FTP v2.0.
     */
    public static final int AUTHENTICATION_CHALLENGE_SIZE = 20;

    /**
     * Common Odette FTP port for non-secure connection is 3305.
     */
    public static final int DEFAULT_OFTP_PORT = 3305;

    /**
     * Odette FTP v2.0 secure connection port is 6619.
     */
    public static final int DEFAULT_SECURE_OFTP_PORT = 6619;

    public static final int DEFAULT_CLIENT_CONNECT_ATTEMPTS = 3;

    public static final int DEFAULT_CLIENT_CONNECT_RETRY_INTERVAL = 30;

}
